:mod:`art.defences.trainer`
===========================
.. automodule:: art.defences.trainer

Trainer
-------
.. autoclass:: Trainer
   :members:
   :special-members:

Adversarial Training
--------------------
.. autoclass:: AdversarialTrainer
   :members:
   :special-members:

Adversarial Training Madry PGD
------------------------------
.. autoclass:: AdversarialTrainerMadryPGD
   :members:
   :special-members:
